@@ -97,6 +97,13 @@ class TaskAssignator:
                                 respuesta.update({'added': True})
                                 element = scheduler.stations.get(
                                     ids).get(self.code_filter)
+                                msg = "Adding new station to sta" +\
+                                f"assigned ipt {ipt} -> ico {ico} ->"+\
+                                f"ids {ids}"
+                                level = 20
+                                scheduler.queue_log.put(("Assignator",
+                                                         msg, level, {}))
+
                                 dt_group.remove(element)
 
                         elif dt_status == 'ALL':
@@ -107,9 +114,13 @@ class TaskAssignator:
                                 ids, ipt, self.counter)
                             assigned_ids.add(ids)
                             self.locker.acquire()
-                            print("Adding new station to sta" +\
+                            msg = "Adding new station to sta" +\
                             f"assigned ipt {ipt} -> ico {ico} ->"+\
-                            f"ids {ids}")
+                            f"ids {ids}"
+                            level = 20
+                            scheduler.queue_log.put(("Assignator",
+                                                     msg, level, {}))
+
                             print(self.scheduler.assigned_tasks)
                             self.scheduler.add_sta_assigned(
                                 ipt, ico, ids)
@@ -118,9 +129,12 @@ class TaskAssignator:
                                               True})
                         self.queue_ans.put(respuesta)
                     else:
-                        print(now(), "Assignator", "All slots are"+\
-                              f"used, can't add the station {code} ids {ids}")
-
+                        msg = f"All slots are "+\
+                              f"used, can't add the station {code} ids {ids}"
+                        print(now(), "Assignator", msg)
+                        level = 30 #warning
+                        scheduler.queue_log.put(("Assignator", msg,
+                                                 level, {}))
                 queue_tasks.task_done()
             else:
                 pass
