@@ -31,7 +31,7 @@ class TaskScheduler:
         Is a generic init method, the inputs required are
         """
         self.ipt = kwargs.get('ipt', [])
-        self.ico = kwargs.get('ico', [])
+        self.ico = kwargs.get('ico', set())
         self.assigned_tasks = kwargs.get('assigned_tasks', {})
         self.lnproc = kwargs.get('nproc', 3)
         self.sta_init = kwargs.get("sta_init", {})
@@ -54,7 +54,7 @@ class TaskScheduler:
                 ipt = my_random_string(uin)
         return ipt
 
-    def set_ico(self, uin=4):
+    def set_ico(self, ico):
         """
         Defines a new id for task related to collect data
         inside a worker, check if exists
@@ -63,13 +63,14 @@ class TaskScheduler:
 
         :returns: a new key from ico
         """
-        ico = my_random_string(uin)
-        while True:
-            if ico not in self.ico:
-                self.ico.append(ico)
-                break
-            else:
-                ico = my_random_string(uin)
+        # ico = my_random_string(uin)
+        # while True:
+        #     if ico not in self.ico:
+        #         self.ico.append(ico)
+        #         break
+        #     else:
+        #         ico = my_random_string(uin)
+        self.ico.append(ico)
         return ico
 
     async def run_task(self, *args):
@@ -352,7 +353,7 @@ class TaskScheduler:
         new_dict = {}
         # inicia n tareas en proceados
         for i in range(self.lnproc):
-            ico = self.set_ico()
+            ico = self.set_ico(f"ICO_{i}")
             nd = {ico:  None}
             new_dict.update(nd)
         self.assigned_tasks[ipt] = new_dict
